#
# spec file for package perl-local-lib
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name local-lib
Name:           perl-local-lib
Version:        2.000029
Release:        1.1
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Create and use a local lib/ for perl modules with PERL5LIB
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HA/HAARG/%{cpan_name}-%{version}.tar.gz
Source1:        perl-homedir.sh
Source2:        perl-homedir.csh
Source3:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN) >= 1.82
BuildRequires:  perl(ExtUtils::Install) >= 1.43
BuildRequires:  perl(ExtUtils::MakeMaker) >= 7.00
BuildRequires:  perl(Module::Build) >= 0.360000
Requires:       perl(CPAN) >= 1.82
Requires:       perl(ExtUtils::Install) >= 1.43
Requires:       perl(ExtUtils::MakeMaker) >= 7.00
Requires:       perl(Module::Build) >= 0.360000
%{perl_requires}

%description
This module provides a quick, convenient way of bootstrapping a user-local
Perl module library located within the user's home directory. It also
constructs and prints out for the user the list of environment variables
using the syntax appropriate for the user's current shell (as specified by
the 'SHELL' environment variable), suitable for directly adding to one's
shell configuration file.

More generally, local::lib allows for the bootstrapping and usage of a
directory containing Perl modules outside of Perl's '@INC'. This makes it
easier to ship an application with an app-specific copy of a Perl module,
or collection of modules. Useful in cases like when an upstream maintainer
hasn't applied a patch to a module of theirs that you need for your
application.

On import, local::lib sets the following environment variables to
appropriate values:

* PERL_MB_OPT

* PERL_MM_OPT

* PERL5LIB

* PATH

* PERL_LOCAL_LIB_ROOT

When possible, these will be appended to instead of overwritten entirely.

These values are then available for reference by any code after import.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
# MANUAL BEGIN
install -d "%{buildroot}%{_sysconfdir}/profile.d"
install -m0644 "%{SOURCE1}" "%{SOURCE2}" "%{buildroot}%{_sysconfdir}/profile.d/"
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%package -n perl-homedir
Summary:        Per-user Perl local::lib setup
Group:          Development/Libraries/Perl
Requires:       %{name} = %{version}-%{release}
Requires:       /usr/bin/cpan

%description -n perl-homedir
perl-homedir configures the system to automatically create a ~/perl5
directory in each user's $HOME on user login.  This allows each user to
install and CPAN packages via the CPAN to their $HOME, with no additional
configuration or privliges, and without installing them system-wide.

If you want your users to be able to install and use their own Perl modules,
install this package.

%files -n perl-homedir
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/profile.d/*

%changelog
* Mon Aug  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.000029:
  - fix taint protection code to delete environment variables rather than
    leaving them as an empty string.
  - fix author test for CPAN.pm's bootstrapping process to work with new
    versions
- Changes from.version 2.000028
  - fix skips in shell test when shell has unpredictable startup actions
- Changes from version 2.000027:
  - releasing as stable
- Changes from version 2.000026:
  - fix output redirection used in fish shell to work with newer versions
  - fix optional function used on Win32 for finding the current directory
- Changes from version 2.000025
  - add documentation for --quiet option
  - added --always option to always add requested directory to env vars, even
    if they are already included
  - improve shell test to be more resiliant against custom init scripts
  - improved test diagnostics
  - reorganized documentation for bootstrapping into a non-standard directory
  - remove mentions of File::HomeDir from documentation, as it is no longer
    used
* Tue Sep 14 2021 Dirk Stoecker <opensuse@dstoecker.de>
- refresh spec file, use cpanspec compatible build
* Sat Oct 17 2020 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 2.000024 - 2017-10-08
  - be compatible with CPAN.pm 1.82 to 1.86_51 during bootstrap process
* Fri Jun  9 2017 coolo@suse.com
- updated to 2.000023
  see /usr/share/doc/packages/perl-local-lib/Changes
  2.000023 - 2017-06-07
  - fix use of 'note' in test for compatibilty with old Test::More
  2.000022 - 2017-06-07
  - releasing as stable
  2.000_021 - 2017-04-23
  - account for an empty SHELL variable when detecting shell
  - author test cleanups
  - bootstrapping option --no-manpages now affects bootstrapping process, not
    just later module installs
  - cope with home directories with spaces when bootstrapping with old CPAN.pm
  2.000_020 - 2016-10-18
  - fix handling of inc_version_list
  - don't load strict or warnings outside author mode
  - load and use Cwd when we're printing and exiting
  - use loaded Cwd/Win32::Cwd if it's available
  - handle relative paths in current executable
  - don't try to run current executable in embedded perl
  - handle relative directories better
  - fix shell test for powershell 1 and group policy restricted environments
  - avoid user init files in shell test
  - use safer format to check environment in shell test
  - many test cleanups
* Fri May 20 2016 coolo@suse.com
- update to 2.00019
  - fix bootstrapping into directory with spaces (PR#4)
  - fix variable interpolation to work when used with sh -u (RT#112711)
  - author test enhancements
* Sun Nov 22 2015 coolo@suse.com
- update to 2.00018
  2.000018 - 2015-10-29
  - repair CPAN.pm bootstrapping broken by extraneous prerequisite.
  - ensure directories are created in correct order to avoid errors
  2.000017 - 2015-10-06
  - fix shell quoting for fish shell
  - work around issue where some cpanm versions wouldn't upgrade
    ExtUtils::MakeMaker in some cases it should have
  - added --quiet option to surpress directory creation message
  - build_environment_vars_for, build_activate_environment_vars_for, and
    environment_vars_string_for options will always include directories being
    added, even if they were already in current ENV vars
  - fixes for author tests
  - create directory structure under created local::libs, ensuring arch dirs
    will always be added to @INC by perl
  - only cause CPAN.pm to prefer ExtUtils::MakeMaker over Module::Build during
    bootstrap process, not after
  - bootstrap process refactored
* Sat Feb  7 2015 coolo@suse.com
- updated to 2.000015
  - Avoid using += in Makefile when bootstrapping for portability (RT#100797)
  - adjust quoting of paths with spaces to work with ExtUtils::MakeMaker 7.0,
    and bump our EUMM prereq to 7.0.
  - fix shell test for shells where we can't prevent some rc files from being
    loaded, like zsh (RT#99819).
* Mon Sep 15 2014 coolo@suse.com
- updated to 2.000014
  - fix taint-mode test in some cases on case insensitive filesystems
  2.000013 - 2014-08-16
  - fix test failure in ActiveState perl
  - better test diagnostics
  - fix quoting of spaces for fish shell (rt#95268)
  - improve quoting for use with cmd.exe
  - fix quoting any arbitrary character when contructing strings for bash
  - skip testing use with shells if the shell doesn't work at all
  2.000012 - 2014-05-12
  - restore build_activate_environment_vars_for,
    build_deactivate_environment_vars_for, build_deact_all_environment_vars_for
    methods for perlbrew compatibility
  - fix transforming relative paths to absolute paths in older perls
  - fix quoting for fish shell
  2.000011 - 2014-04-02
  - more fixes for issue where PERL5LIB Carp is not the same version as in the
    local-lib
  2.000010 - 2014-03-28
  - fix shell test on cygwin
  2.000_009 - 2014-03-15
  - no longer loads File::Spec, so an upgraded version installed inside a local
    lib dir can be used by scripts
* Sat Mar 15 2014 coolo@suse.com
- updated to 2.000008
  - even more relaxed shell output testing
  - only test shells in /etc/shells
  - fix Makefile.PL on solaris
  2.000006 - 2014-03-07
  - fix bootstrapping not auto-configuring in some cases
  - more relaxed shell output testing
  - use normal arguments to be used on the command line in addition to import
    arguments
  - support fish shell
  - stop trying to test csh/sh on Win32
  - work around CPAN.pm issues with checking prerequisites
  2.000004 - 2014-01-03
  - fix errors in PowerShell output when clearing nonexistant variables
  - fix shell test to avoid extremely long lines
  - fix shell test to avoid testing standard Win32 shells on Cygwin
  - improved diagnostics in shell test
  2.000003 - 2013-12-30
  - releasing 2.000_002 as stable
  2.000_002 - 2013-12-25
  - fix CPAN setup error check in Makefile.PL
  - fix install test warnings
  - fix shell test to skip cmd/powershell startup scripts
* Mon Nov 25 2013 coolo@suse.com
- updated to 1.008026
  - drop perl prerequisite to 5.6, since everything works there.
  - fix install test on cygwin
  - fix stackable test on win32 and when external local::lib is set
  - clarify errors in Makefile.PL about CPAN configuration
  - adjust csh output to allow use directly by eval
  - silence a possible warning in Makefile.PL
  - add additional docs about combining local::lib with lib::core::only
  - reverse order of PERL_LOCAL_LIB_ROOT.  new local::libs are now added
    to the beginning instead of the end, to match the order of other
    similar environment variables.
  - fix installation into directories with spaces or backslashes, as
    well as Win32 test failures when Capture::Tiny is installed
  - fix test breaking in some cases when an external local::lib is set
  - fix test compatibility with old versions of Exporter
  - stable release of 1.008022 (no code changes since 1.008012)
  - see 1.008019 through 1.008021
  - yet another attempt to overcome win32 testing issues (paths with
    spaces, backslashes)
  - yet another attempt to overcome win32 testing issues (paths with
    spaces, backslashes)
  - another attempt to overcome win32 testing issues (paths with spaces,
    backslashes)
* Fri Oct  4 2013 coolo@suse.com
- update to 1.008018
  - print out actual paths in more test cases, for helping to diagnose
    mysterious failures
  - avoid "Unrecognized escape \s passed through" errors on win32
    (again)
  - avoid "Unrecognized escape \s passed through" errors on win32
  - fix new test to use alternate path representations on windows, to
    handle potential space issues (regression since 1.008012)
  - fix undef value errors when not installing into a local::lib
  - now handling using -Mlocal::lib in a taintperl environment, by
    ensuring that all libs in PERL_LOCAL_LIB_ROOT are properly added to
    @INC (RT#76661, Karen Etheridge)
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.008011
  - skip CPAN workaround if running via cpanminus  (miyagawa, RT#85731)
* Tue Jun 11 2013 coolo@suse.com
- updated to 1.008010
  - Fix a split on undefined value warning (David Golden -- see
    https://github.com/gugod/App-perlbrew/issues/305)
  - Remove Carp::Always dep
  - Fix putting arch path in PERL5LIB
  - Refactor Win32 path handling out of ensure_dir_structure_for()
  - Fix activate_paths when PERL_LOCAL_LIB_ROOT starts with :
  - Fix ~/perl5/bin missing in $PATH
  - Back to 1.008004 with Carp fix since subsequent releases were botched
  - Avoid issue where PERL5LIB Carp is older than local::lib one
* Fri Feb 25 2011 pascal.bleser@opensuse.org
- update to 1.008004: no user-visible changes
- changes from 1.008002:
  * add local::lib stacking support
  * add activation/deactivation support
- changes from 1.008001:
  * bootstrap Module::Build just like ExtUtils::MakeMaker
- changes from 1.008000:
  * print_environment_vars_for() refactored with separate function
    environment_vars_string_for()
  * PERL_LOCAL_LIB_ROOT environment is added to disambiguate when PERL_MM_OPT,
    etc. was set by local::lib or other means
- changes from 1.006009:
  * split up method guess_shelltype from parts of print_environment_vars_for
  * updated documentation about change of use with .modulebuildrc
- changes from 1.006008:
  * finally move to PERL_MB_OPT rather than using .modulebuildrc
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Aug 26 2010 pascal.bleser@opensuse.org
- update to 1.006007:
  * fixing stuff so that search.cpan.org displays right
  * documented one method in all languages
- changes from 1.006006:
  * added portuguese translation
  * several minor fixes in the documentation
  * changed methods look in documentation
* Thu Jul 15 2010 pascal.bleser@opensuse.org
- update to 1.006005:
  * added support informations (also for german)
  * fixed newline in german translation from DOS2UNIX
* Sat Jun 12 2010 pascal.bleser@opensuse.org
- update to 1.006004:
  * added german translation
  * enhanced some parts of english documentation
  * reverse the perl/arch paths in PERL5LIB
* Thu Apr  1 2010 pascal.bleser@opensuse.org
- update to 1.006000:
  * create lib::core::only that provides the "set @INC to core dirs only" functionality that was the only part of --self-contained that ever worked usefully
  * delete broken --self-contained flag from core
* Sun Mar 14 2010 pascal.bleser@opensuse.org
- update to 1.005001
- changes from 1.005000:
  * more robust handling of running new toolchains on older perls
  * warnings for missing PATH/PERL5LIB (as when not running interactively) silenced
  * start of better docs for C<--self-contained>
* Wed Feb  3 2010 pascal.bleser@opensuse.org
- new package, ported from Fedora 13
